#![no_std]
#![no_main]
use cortex_m::peripheral::{syst, Peripherals};
use cortex_m_rt::{entry, exception};
use cortex_m_semihosting::hprintln;

use nrf52_hal as hal;

use panic_semihosting as _;

const F_CPU:u32 = 64_000_000;

static mut FIRE_1S:bool = false;

#[entry]
fn main() -> ! {
    hprintln!("Hello, world!").unwrap();

    let peripherals = Peripherals::take().unwrap();
    let mut systick = peripherals.SYST;
    systick.set_clock_source(syst::SystClkSource::Core);
    systick.set_reload(F_CPU / 1000 - 1);
    systick.clear_current();
    systick.enable_interrupt();
    systick.enable_counter();

    let nrf_peripherals = hal::Peripherals::take().unwrap();
    let p0 = nrf_peripherals.P0;

    unsafe {
        p0.outset.write(|w| w.bits(1 << 17));
        p0.pin_cnf[17].write(|w| {
            w.input().disconnect();
            w.dir().output();
            w
        });
    }

    let mut state:bool = false;
    loop {
        unsafe {
            if FIRE_1S {
                FIRE_1S = false;
                if state {
                    hprintln!("off").unwrap();
                    p0.outclr.write(|w| w.bits(1 << 17));
                    state = false;
                } else {
                    hprintln!("on").unwrap();
                    p0.outset.write(|w| w.bits(1 << 17));
                    state = true;
                }
            }
        }
    }
}

#[exception]
fn SysTick() {
    static mut CNT:u32 = 0;
    *CNT += 1;
    if *CNT == 1000 {
        *CNT = 0;
        unsafe {
            FIRE_1S = true;
        }
    }
}
